/*
 * tcan114x_SPI.h
 * Description: This file is responsible for abstracting the lower-level microcontroller SPI read and write functions
 *
 * Created on: December 4, 2018
 *     Author: Texas Instruments
 *
 *
 * Copyright (c) 2017 Texas Instruments Incorporated.  All rights reserved.
 * Software License Agreement
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the
 * distribution.
 *
 * Neither the name of Texas Instruments Incorporated nor the names of
 * its contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef TCAN114X_SPI_H_
#define TCAN114X_SPI_H_

//Had to change this from <driverlib.h>
#include "driverlib/MSP430FR5xx_6xx/driverlib.h"

/* ********************************** *
 *  Start of device-specific defines
 * ********************************** */
#ifdef __MSP430FR6989__
#define SPI_CS_GPIO_PORT                GPIO_PORT_P2
#define SPI_CS_GPIO_PIN                 GPIO_PIN5
#define SPI_HW_ADDR                     EUSCI_B0_BASE

// MSP430 Specific commands to proper sequencing on the SPI bus
#define WAIT_FOR_TRANSMIT               while (!(HWREG16(SPI_HW_ADDR + OFS_UCBxIFG) & UCTXIFG))
#define WAIT_FOR_IDLE                   while ((HWREG16(SPI_HW_ADDR + OFS_UCBxSTATW) & UCBUSY))
#endif
/* ******************************** *
 *  End of device-specific defines
 * ******************************** */
#define SPI_WRITE_OPCODE                            0x01
#define SPI_READ_OPCODE                             0x00

//--------------------------------------------------------------------------
//                          Write Functions
//------------------------------------------------------------------------

/* TCAN_WRITE
 * Description: Writes a single 8-bit word to the specified register address from an address pointer, returns the  interrupt register
 */
uint8_t TCAN_WRITE(uint8_t address, uint8_t* data);

/* TCAN_WRITE_BURST
 * Description: Writes multiple 8-bit words to the specified register address. Data is written from the data array. Function returns interrupt data
 */
uint8_t TCAN_WRITE_BURST(uint8_t address, uint8_t numBytes, uint8_t data[]);

//--------------------------------------------------------------------------
//                          Read Functions
//--------------------------------------------------------------------------
/* TCAN_READ
 * Description: Reads a single 8-bit word from the specified register address. Data is written to data pointer. Function returns interrupt data
 */
uint8_t TCAN_READ(uint8_t address, uint8_t* data);

/* TCAN_READ_BURST
 * Description: Reads multiple 8-bit words from the specified register address. Data read is stored to data pointer. Function returns interrupt data
 */
uint8_t TCAN_READ_BURST(uint8_t address, uint8_t numBytes, uint8_t data[]);

//-----------------------------------------------------------------------------------------------

#endif
